#[cfg(feature = "server")]
use rusqlite::{types::ToSqlOutput, ToSql};
use serde::{Deserialize, Serialize};

#[derive(Clone, Copy, Debug, Serialize, Deserialize)]
pub enum Store {
	Aldi,
	Edeka,
	Dm,
	Lidl,
	Rewe,
	Tegut,
}

impl Into<String> for &Store {
	fn into(self) -> String {
		String::from(match *self {
			Store::Aldi => "aldi",
			Store::Edeka => "edeka",
			Store::Dm => "dm",
			Store::Lidl => "lidl",
			Store::Rewe => "rewe",
			Store::Tegut => "tegut",
		})
	}
}

impl TryFrom<&str> for Store {
	type Error = ();

	fn try_from(s: &str) -> Result<Self, Self::Error> {
		match s {
			"aldi" => Ok(Store::Aldi),
			"edeka" => Ok(Store::Edeka),
			"dm" => Ok(Store::Dm),
			"lidl" => Ok(Store::Lidl),
			"rewe" => Ok(Store::Rewe),
			"tegut" => Ok(Store::Tegut),
			_ => Err(()),
		}
	}
}

#[cfg(feature = "server")]
impl ToSql for Store {
	fn to_sql(&self) -> rusqlite::Result<ToSqlOutput<'_>> {
		match self {
			Store::Aldi => 0.to_sql(),
			Store::Edeka => 1.to_sql(),
			Store::Dm => 2.to_sql(),
			Store::Lidl => 3.to_sql(),
			Store::Rewe => 4.to_sql(),
			Store::Tegut => 5.to_sql(),
		}
	}
}
